github

package
v0.28.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 23, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetToken

func GetToken() string

retrieves gh token from multiple sources in order of preference: 1. viper config (used by CLI) 2. environment variables (GITHUB_TOKEN, GH_TOKEN, GITHUB_AUTH_TOKEN)

func NewClient

func NewClient() (*github.Client, error)

creates a new GitHub client with authentication token. returns a client with auth token if available, or unauthenticated client otherwise.

Types

This section is empty.

Jump to